## 0.3.0 (2024-03-24)

### Feat

- bumping minor, finally pypi working?

## 0.2.0 (2024-03-24)

### Feat

- force minor bump to test CI

### Fix

- still figuring pypi CI

## 0.1.3 (2024-03-23)

### Fix

- another fake bump to test CI

## 0.1.2 (2024-03-23)

### Fix

- fake bugfix to trigger tag bump

## 0.1.1 (2024-03-22)

### Fix

- added lint deps to readthedocs config

## 0.1.0 (2024-03-18)

### Feat

- trying to break docs, shouldnt work

### Fix

- added dot to sphinx dir, now works nice with pydocstyle

## 0.0.2 (2024-03-10)

### Fix

- test
- black triggered in precommit?
